@@ -110,11 +110,11 @@
 #' n <- 200
 #' x1 = rnorm(n); x2 = rnorm(n)
 #' tmpdata = data.frame(x1 = x1, x2 = x2, y = rnorm(n) + x1 + 2*x2)
-#' modbinning <- ormBD(y ~ x1 + x2, data = tmpdata, family = loglog,
+#' modbinning <- ormBD(y ~ x1 + x2, data = tmpdata, family = "loglog",
 #'                      approach = "binning", target_num = 100)
-#' ## modrounding <- ormBD(y ~ x1 + x2, data = tmpdata, family = loglog,
+#' ## modrounding <- ormBD(y ~ x1 + x2, data = tmpdata, family = "loglog",
 #' ##                     approach = "rounding", target_num = 100)
-#' ## moddivcomb <- ormBD(y ~ x1 + x2, data = tmpdata, family = loglog,
+#' ## moddivcomb <- ormBD(y ~ x1 + x2, data = tmpdata, family = "loglog",
 #' ##                     approach = "divide-combine", target_num = 100)
 #'
 #' @references Liu et
@@ -124,7 +124,7 @@
 #'     al. "Fitting semiparametric cumulative probability models for big data."
 #'     (2023) (submitted)
 #'
-#' @importFrom rms orm
+#' @importFrom rms orm infoMxop
 #' @importFrom Hmisc na.delete
 #' @importFrom stats model.extract
 #' @importFrom benchmarkme get_ram
@@ -335,6 +335,7 @@ orm_binning <- function(res,target_num){
   }
   res
 }
+  
 
 orm_indi <- function(formula, data, ...){
   orm0 <- orm(formula, data = data, ...)
@@ -344,7 +345,8 @@ orm_indi <- function(formula, data, ...){
 
   coef <- orm0$coefficients
   coef[1 : len] <- -coef[1 : len]
-  var <- SparseM::as.matrix(SparseM::solve(orm0$info.matrix))
+  #var <- SparseM::as.matrix(SparseM::solve(orm0$info.matrix))
+  var <- infoMxop(orm0$info.matrix, invert = TRUE)
 
   ## coefficients now has the corrent sign for alpha
   ## alphaVariance only has the diagonal values from the variance matrix
